function [w,sigt,norm]  =getLachauxWavelet(fzero,timing,verbose)
%given in lachaux 1999 paper: long complex morlet wavelet
% fzero: center frequency
% timing: sampling rate (using time range of -3sigt:+3sigt)
%			or timepoints to calculate the wavelet
%
%by Stefan Scherbaum 2006

sigt=7/(fzero);%Difference to Tallon Baudry: *pi*2;

if size(timing,2)==1
    %timing defines sampling rate, time is defined by sigt
    %first create precise wavelet, than downsample
    fs=timing;
    ts=-3*sigt:1/fs:sigt*3;
else
    %timing means all interesting points in time
    ts=timing;
    fs=0;
end

%normalization for total energy=1 (whatever that means exactly?)
norm=(sigt*sqrt(pi))^(-1/2);
w=norm.*exp(-ts.^2/(2*sigt^2)).*exp(2*j*pi*fzero.*ts);
%if samplingrate was sepcified, downsample to samplingrate
if nargin>3 & verbose 
    fprintf(['\nMorlet-Wavelet for fzero=',num2str(fzero)]);
    fprintf(['\nSigma_T=',num2str(sigt)]);
    fprintf(['\nNormalization=',num2str(norm)]);
    fprintf('\n');
end

